@@ -164,12 +164,16 @@ def __ensure_provisioning_reads(
 
     update_needed = False
     try:
+        lookback_window_start = get_gsi_option(
+            table_key, gsi_key, 'lookback_window_start')
         current_read_units = dynamodb.get_provisioned_gsi_read_units(
             table_name, gsi_name)
         consumed_read_units_percent = \
-            gsi_stats.get_consumed_read_units_percent(table_name, gsi_name)
+            gsi_stats.get_consumed_read_units_percent(
+                table_name, gsi_name, lookback_window_start)
         throttled_read_count = \
-            gsi_stats.get_throttled_read_event_count(table_name, gsi_name)
+            gsi_stats.get_throttled_read_event_count(
+                table_name, gsi_name, lookback_window_start)
         reads_upper_threshold = \
             get_gsi_option(table_key, gsi_key, 'reads_upper_threshold')
         reads_lower_threshold = \
@@ -227,30 +231,73 @@ def __ensure_provisioning_reads(
             'Scaling down reads is not done when usage is at 0%'.format(
                 table_name, gsi_name))
 
+    # Increase needed due to high CU consumption
     elif consumed_read_units_percent >= reads_upper_threshold:
 
-        if increase_reads_unit == 'percent':
-            calculated_provisioning = calculators.increase_reads_in_percent(
-                current_read_units,
-                increase_reads_with,
-                get_gsi_option(table_key, gsi_key, 'max_provisioned_reads'),
-                '{0} - GSI: {1}'.format(table_name, gsi_name))
+        # Exit if up scaling has been disabled
+        if not get_gsi_option(table_key, gsi_key, 'enable_reads_up_scaling'):
+            logger.debug(
+                '{0} - GSI: {1} - Up scaling event detected. '
+                'No action taken as scaling '
+                'up reads has been disabled in the configuration'.format(
+                    table_name, gsi_name))
         else:
-            calculated_provisioning = calculators.increase_reads_in_units(
-                current_read_units,
-                increase_reads_with,
-                get_gsi_option(table_key, gsi_key, 'max_provisioned_reads'),
-                '{0} - GSI: {1}'.format(table_name, gsi_name))
+            if increase_reads_unit == 'percent':
+                calculated_provisioning = calculators.increase_reads_in_percent(
+                    current_read_units,
+                    increase_reads_with,
+                    get_gsi_option(table_key, gsi_key, 'max_provisioned_reads'),
+                    '{0} - GSI: {1}'.format(table_name, gsi_name))
+            else:
+                calculated_provisioning = calculators.increase_reads_in_units(
+                    current_read_units,
+                    increase_reads_with,
+                    get_gsi_option(table_key, gsi_key, 'max_provisioned_reads'),
+                    '{0} - GSI: {1}'.format(table_name, gsi_name))
 
-        if current_read_units != calculated_provisioning:
-            logger.info(
-                '{0} - Resetting the number of consecutive '
-                'read checks. Reason: scale up event detected'.format(
-                    table_name))
-            num_consec_read_checks = 0
-            update_needed = True
-            updated_read_units = calculated_provisioning
+            if current_read_units != calculated_provisioning:
+                logger.info(
+                    '{0} - Resetting the number of consecutive '
+                    'read checks. Reason: scale up event detected'.format(
+                        table_name))
+                num_consec_read_checks = 0
+                update_needed = True
+                updated_read_units = calculated_provisioning
 
+    # Decrease needed due to low CU consumption
+    elif consumed_read_units_percent <= reads_lower_threshold:
+
+        # Exit if down scaling has been disabled
+        if not get_gsi_option(table_key, gsi_key, 'enable_reads_down_scaling'):
+            logger.debug(
+                '{0} - GSI: {1} - Down scaling event detected. '
+                'No action taken as scaling '
+                'down reads has been disabled in the configuration'.format(
+                    table_name, gsi_name))
+        else:
+            if decrease_reads_unit == 'percent':
+                calculated_provisioning = calculators.decrease_reads_in_percent(
+                    current_read_units,
+                    decrease_reads_with,
+                    get_gsi_option(table_key, gsi_key, 'min_provisioned_reads'),
+                    '{0} - GSI: {1}'.format(table_name, gsi_name))
+            else:
+                calculated_provisioning = calculators.decrease_reads_in_units(
+                    current_read_units,
+                    decrease_reads_with,
+                    get_gsi_option(table_key, gsi_key, 'min_provisioned_reads'),
+                    '{0} - GSI: {1}'.format(table_name, gsi_name))
+
+            if current_read_units != calculated_provisioning:
+                # We need to look at how many times the num_consec_read_checks
+                # integer has incremented and Compare to config file value
+                num_consec_read_checks = num_consec_read_checks + 1
+
+                if num_consec_read_checks >= num_read_checks_before_scale_down:
+                    update_needed = True
+                    updated_read_units = calculated_provisioning
+
+    # Increase needed due to high throttling
     elif throttled_read_count > throttled_reads_upper_threshold:
 
         if throttled_reads_upper_threshold > 0:
@@ -277,30 +324,7 @@ def __ensure_provisioning_reads(
                 update_needed = True
                 updated_read_units = calculated_provisioning
 
-    elif consumed_read_units_percent <= reads_lower_threshold:
-
-        if decrease_reads_unit == 'percent':
-            calculated_provisioning = calculators.decrease_reads_in_percent(
-                current_read_units,
-                decrease_reads_with,
-                get_gsi_option(table_key, gsi_key, 'min_provisioned_reads'),
-                '{0} - GSI: {1}'.format(table_name, gsi_name))
-        else:
-            calculated_provisioning = calculators.decrease_reads_in_units(
-                current_read_units,
-                decrease_reads_with,
-                get_gsi_option(table_key, gsi_key, 'min_provisioned_reads'),
-                '{0} - GSI: {1}'.format(table_name, gsi_name))
-
-        if current_read_units != calculated_provisioning:
-            # We need to look at how many times the num_consec_read_checks
-            # integer has incremented and Compare to config file value
-            num_consec_read_checks = num_consec_read_checks + 1
-
-            if num_consec_read_checks >= num_read_checks_before_scale_down:
-                update_needed = True
-                updated_read_units = calculated_provisioning
-
+    # Never go over the configured max provisioning
     if max_provisioned_reads:
         if int(updated_read_units) > int(max_provisioned_reads):
             update_needed = True
@@ -345,12 +369,16 @@ def __ensure_provisioning_writes(
 
     update_needed = False
     try:
+        lookback_window_start = get_gsi_option(
+            table_key, gsi_key, 'lookback_window_start')
         current_write_units = dynamodb.get_provisioned_gsi_write_units(
             table_name, gsi_name)
         consumed_write_units_percent = \
-            gsi_stats.get_consumed_write_units_percent(table_name, gsi_name)
+            gsi_stats.get_consumed_write_units_percent(
+                table_name, gsi_name, lookback_window_start)
         throttled_write_count = \
-            gsi_stats.get_throttled_write_event_count(table_name, gsi_name)
+            gsi_stats.get_throttled_write_event_count(
+                table_name, gsi_name, lookback_window_start)
         writes_upper_threshold = \
             get_gsi_option(table_key, gsi_key, 'writes_upper_threshold')
         writes_lower_threshold = \
@@ -406,30 +434,76 @@ def __ensure_provisioning_writes(
             'Scaling down writes is not done when usage is at 0%'.format(
                 table_name, gsi_name))
 
+    # Increase needed due to high CU consumption
     elif consumed_write_units_percent >= writes_upper_threshold:
 
-        if increase_writes_unit == 'percent':
-            calculated_provisioning = calculators.increase_writes_in_percent(
-                current_write_units,
-                increase_writes_with,
-                get_gsi_option(table_key, gsi_key, 'max_provisioned_reads'),
-                '{0} - GSI: {1}'.format(table_name, gsi_name))
-        else:
-            calculated_provisioning = calculators.increase_writes_in_units(
-                current_write_units,
-                increase_writes_with,
-                get_gsi_option(table_key, gsi_key, 'max_provisioned_reads'),
-                '{0} - GSI: {1}'.format(table_name, gsi_name))
-
-        if current_write_units != calculated_provisioning:
-            logger.info(
-                '{0} - GSI: {1} - Resetting the number of consecutive '
-                'write checks. Reason: scale up event detected'.format(
+        # Exit if up scaling has been disabled
+        if not get_gsi_option(table_key, gsi_key, 'enable_writes_up_scaling'):
+            logger.debug(
+                '{0} - GSI: {1} - Up scaling event detected. '
+                'No action taken as scaling '
+                'up writes has been disabled in the configuration'.format(
                     table_name, gsi_name))
-            num_consec_write_checks = 0
-            update_needed = True
-            updated_write_units = calculated_provisioning
+        else:
+            if increase_writes_unit == 'percent':
+                calculated_provisioning = \
+                    calculators.increase_writes_in_percent(
+                        current_write_units,
+                        increase_writes_with,
+                        get_gsi_option(
+                            table_key, gsi_key, 'max_provisioned_reads'),
+                        '{0} - GSI: {1}'.format(table_name, gsi_name))
+            else:
+                calculated_provisioning = calculators.increase_writes_in_units(
+                    current_write_units,
+                    increase_writes_with,
+                    get_gsi_option(table_key, gsi_key, 'max_provisioned_reads'),
+                    '{0} - GSI: {1}'.format(table_name, gsi_name))
 
+            if current_write_units != calculated_provisioning:
+                logger.info(
+                    '{0} - GSI: {1} - Resetting the number of consecutive '
+                    'write checks. Reason: scale up event detected'.format(
+                        table_name, gsi_name))
+                num_consec_write_checks = 0
+                update_needed = True
+                updated_write_units = calculated_provisioning
+
+    # Decrease needed due to low CU consumption
+    elif consumed_write_units_percent <= writes_lower_threshold:
+
+        # Exit if down scaling has been disabled
+        if not get_gsi_option(table_key, gsi_key, 'enable_writes_down_scaling'):
+            logger.debug(
+                '{0} - GSI: {1} - Down scaling event detected. '
+                'No action taken as scaling '
+                'down writes has been disabled in the configuration'.format(
+                    table_name, gsi_name))
+        else:
+            if decrease_writes_unit == 'percent':
+                calculated_provisioning = \
+                    calculators.decrease_writes_in_percent(
+                        current_write_units,
+                        decrease_writes_with,
+                        get_gsi_option(
+                            table_key, gsi_key, 'min_provisioned_writes'),
+                        '{0} - GSI: {1}'.format(table_name, gsi_name))
+            else:
+                calculated_provisioning = calculators.decrease_writes_in_units(
+                    current_write_units,
+                    decrease_writes_with,
+                    get_gsi_option(table_key, gsi_key, 'min_provisioned_reads'),
+                    '{0} - GSI: {1}'.format(table_name, gsi_name))
+
+            if current_write_units != calculated_provisioning:
+                num_consec_write_checks = num_consec_write_checks + 1
+
+                if (num_consec_write_checks >=
+                        num_write_checks_before_scale_down):
+                    update_needed = True
+                    updated_write_units = calculated_provisioning
+
+    # Increase needed due to high throttling
     elif throttled_write_count > throttled_writes_upper_threshold:
 
         if throttled_writes_upper_threshold > 0:
@@ -457,28 +531,7 @@ def __ensure_provisioning_writes(
                 update_needed = True
                 updated_write_units = calculated_provisioning
 
-    elif consumed_write_units_percent <= writes_lower_threshold:
-
-        if decrease_writes_unit == 'percent':
-            calculated_provisioning = calculators.decrease_writes_in_percent(
-                current_write_units,
-                decrease_writes_with,
-                get_gsi_option(table_key, gsi_key, 'min_provisioned_writes'),
-                '{0} - GSI: {1}'.format(table_name, gsi_name))
-        else:
-            calculated_provisioning = calculators.decrease_writes_in_units(
-                current_write_units,
-                decrease_writes_with,
-                get_gsi_option(table_key, gsi_key, 'min_provisioned_reads'),
-                '{0} - GSI: {1}'.format(table_name, gsi_name))
-
-        if current_write_units != calculated_provisioning:
-            num_consec_write_checks = num_consec_write_checks + 1
-
-            if num_consec_write_checks >= num_write_checks_before_scale_down:
-                update_needed = True
-                updated_write_units = calculated_provisioning
-
+    # Never go over the configured max provisioning
     if max_provisioned_writes:
         if int(updated_write_units) > int(max_provisioned_writes):
             update_needed = True
